@@ -1,8 +1,8 @@
-IPA_MSdeconvoluter <- function(HRMS_path, MSfile, MS_level = 1) {
-  p2l <- IDSL.MXP::peak2list(HRMS_path, MSfile)
+IPA_MSdeconvoluter <- function(inputHRMSfolderPath, MSfileName, MSlevel = 1) {
+  p2l <- IDSL.MXP::peak2list(inputHRMSfolderPath, MSfileName)
   scanTable <- p2l[["scanTable"]]
   spectraList <- p2l[["spectraList"]]
-  x_MS <- which(scanTable$peaksCount > 0 & scanTable$msLevel == MS_level) ## some files may not have data in calibration scan acquisitions.
+  x_MS <- which(scanTable$peaksCount > 0 & scanTable$msLevel == MSlevel) ## some files may not have data in calibration scan acquisitions.
   spectraList <- spectraList[x_MS]
   scanTable <- scanTable[x_MS, ]
   retentionTime <- as.numeric(scanTable$retentionTime)  # Retention times in minute
